import { useState, useRef } from 'react'
import { useNavigate } from 'react-router-dom'
import { importChecklistFromJSON } from '../hooks/useLocalStorage'

interface CreateChecklistProps {
  className?: string
}

export default function CreateChecklist({ className = '' }: CreateChecklistProps) {
  const [checklistName, setChecklistName] = useState('')
  const [isCreating, setIsCreating] = useState(false)
  const [isImporting, setIsImporting] = useState(false)
  const fileInputRef = useRef<HTMLInputElement>(null)
  const navigate = useNavigate()

  const createChecklist = async () => {
    if (!checklistName.trim()) return

    setIsCreating(true)
    try {
      const response = await fetch('/api/checklists', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ name: checklistName.trim() }),
      })

      if (response.ok) {
        const data = await response.json()

        // Navigate to the new checklist
        navigate(`/${data.uuid}`)
      } else {
        alert('Failed to create checklist')
      }
    } catch (error) {
      console.error('Error creating checklist:', error)
      alert('Failed to create checklist')
    } finally {
      setIsCreating(false)
      setChecklistName('')
    }
  }

  const handleKeyDown = (e: React.KeyboardEvent) => {
    if (e.key === 'Enter') {
      createChecklist()
    }
  }

  const handleImportChecklist = async (event: React.ChangeEvent<HTMLInputElement>) => {
    const file = event.target.files?.[0]
    if (!file) return

    setIsImporting(true)
    try {
      const newUuid = await importChecklistFromJSON(file)
      navigate(`/${newUuid}`)
    } catch (error) {
      console.error('Error importing checklist:', error)
      alert('Failed to import checklist. Please check the file format.')
    } finally {
      setIsImporting(false)
      // Reset the file input
      if (fileInputRef.current) {
        fileInputRef.current.value = ''
      }
    }
  }

  const triggerFileInput = () => {
    fileInputRef.current?.click()
  }

  return (
    <div className={`bg-white dark:bg-gray-800 rounded-lg shadow-sm border border-gray-200 dark:border-gray-700 p-8 ${className}`}>
      <h2 className="text-2xl font-bold text-gray-900 dark:text-white mb-6">Create New Checklist</h2>
      
      {/* Create new checklist section */}
      <div className="flex flex-col sm:flex-row gap-4 mb-6">
        <input
          type="text"
          placeholder="Enter checklist name..."
          value={checklistName}
          onChange={(e) => setChecklistName(e.target.value)}
          onKeyDown={handleKeyDown}
          disabled={isCreating || isImporting}
          className="flex-1 px-4 py-3 border border-gray-300 dark:border-gray-600 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent disabled:bg-gray-100 dark:disabled:bg-gray-700 disabled:text-gray-500 dark:disabled:text-gray-400 bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
        />
        <button 
          onClick={createChecklist} 
          disabled={isCreating || isImporting || !checklistName.trim()}
          className="
            px-8 py-3 bg-blue-600 dark:bg-blue-500 text-white font-medium rounded-lg hover:bg-blue-700 dark:hover:bg-blue-600
            focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800 disabled:opacity-50
            disabled:cursor-not-allowed transition-colors duration-200
          "
        >
          {isCreating ? 'Creating...' : 'Create'}
        </button>
      </div>

      {/* Import section */}
      <div className="border-t border-gray-200 dark:border-gray-700 pt-6">
        <h3 className="text-lg font-semibold text-gray-900 dark:text-white mb-4">Import Checklist</h3>
        <div className="flex flex-col sm:flex-row gap-4">
          <div className="flex-1">
            <p className="text-sm text-gray-600 dark:text-gray-400 mb-2">
              Import a previously exported checklist JSON file
            </p>
            <input
              ref={fileInputRef}
              type="file"
              accept=".json"
              onChange={handleImportChecklist}
              className="hidden"
            />
          </div>
          <button 
            onClick={triggerFileInput}
            disabled={isCreating || isImporting}
            className="
              px-8 py-3 bg-green-600 dark:bg-green-500 text-white font-medium rounded-lg hover:bg-green-700 dark:hover:bg-green-600
              focus:outline-none focus:ring-2 focus:ring-green-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800 disabled:opacity-50
              disabled:cursor-not-allowed transition-colors duration-200
            "
          >
            {isImporting ? '📥 Importing...' : '📥 Import JSON'}
          </button>
        </div>
      </div>
    </div>
  )
} 